@@ -45,7 +45,7 @@ def reduced_motion_option(fn):
     cls=DefaultGroup,
     default="shot",
     default_if_no_args=True,
-    context_settings=dict(help_option_names=["-h", "--help"]),
+    context_settings=dict(help_option_names=["--help"]),
 )
 @click.version_option()
 def cli():
@@ -134,6 +134,11 @@ def cli():
     is_flag=True,
     help="Interact mode with developer tools",
 )
+@click.option(
+    "--log-requests",
+    type=click.File("w"),
+    help="Log details of all requests to this file",
+)
 @browser_option
 @user_agent_option
 @reduced_motion_option
@@ -156,6 +161,7 @@ def shot(
     timeout,
     interactive,
     devtools,
+    log_requests,
     browser,
     user_agent,
     reduced_motion,
@@ -235,11 +241,17 @@ def shot(
                     shot,
                     return_bytes=True,
                     use_existing_page=use_existing_page,
+                    log_requests=log_requests,
                 )
                 sys.stdout.buffer.write(shot)
             else:
                 shot["output"] = str(output)
-                shot = take_shot(context, shot, use_existing_page=use_existing_page)
+                shot = take_shot(
+                    context,
+                    shot,
+                    use_existing_page=use_existing_page,
+                    log_requests=log_requests,
+                )
         except TimeoutError as e:
             raise click.ClickException(str(e))
         browser_obj.close()
@@ -500,7 +512,49 @@ def javascript(
     "--media-screen", is_flag=True, help="Use screen rather than print styles"
 )
 @click.option("--landscape", is_flag=True, help="Use landscape orientation")
-def pdf(url, auth, output, javascript, wait, media_screen, landscape):
+@click.option(
+    "--format",
+    "format_",
+    type=click.Choice(
+        [
+            "Letter",
+            "Legal",
+            "Tabloid",
+            "Ledger",
+            "A0",
+            "A1",
+            "A2",
+            "A3",
+            "A4",
+            "A5",
+            "A6",
+        ],
+        case_sensitive=False,
+    ),
+    help="Which standard paper size to use",
+)
+@click.option("--width", help="PDF width including units, e.g. 10cm")
+@click.option("--height", help="PDF height including units, e.g. 10cm")
+@click.option(
+    "--scale",
+    type=click.FloatRange(min=0.1, max=2.0),
+    help="Scale of the webpage rendering",
+)
+@click.option("--print-background", is_flag=True, help="Print background graphics")
+def pdf(
+    url,
+    auth,
+    output,
+    javascript,
+    wait,
+    media_screen,
+    landscape,
+    format_,
+    width,
+    height,
+    scale,
+    print_background,
+):
     """
     Create a PDF of the specified page
 
@@ -530,6 +584,11 @@ def pdf(url, auth, output, javascript, wait, media_screen, landscape):
 
         kwargs = {
             "landscape": landscape,
+            "format": format_,
+            "width": width,
+            "height": height,
+            "scale": scale,
+            "print_background": print_background,
         }
         if output != "-":
             kwargs["path"] = output
@@ -632,6 +691,7 @@ def take_shot(
     shot,
     return_bytes=False,
     use_existing_page=False,
+    log_requests=None,
 ):
     url = shot.get("url") or ""
     if not url:
@@ -663,6 +723,28 @@ def take_shot(
 
     if not use_existing_page:
         page = context_or_page.new_page()
+        if log_requests:
+
+            def on_response(response):
+                try:
+                    body = response.body()
+                    size = len(body)
+                except Error:
+                    size = None
+                log_requests.write(
+                    json.dumps(
+                        {
+                            "method": response.request.method,
+                            "url": response.url,
+                            "status": response.status,
+                            "size": size,
+                            "timing": response.request.timing,
+                        }
+                    )
+                    + "\n"
+                )
+
+            page.on("response", on_response)
     else:
         page = context_or_page
 
